fig812 <- function(post=F)
{
 if(post)
  {#ps.options (colors=ps.colors.rgb[c("blue", "magenta", "cyan",
   #"green", "MediumBlue", "red", "black", "yellow", "blue"),])
    postscript("Fig812.ps", width=4.4, height=4.5, horizontal=F,
	pointsize=8)
  }
 else {if(dev.cur()==1) motif(); par(ask=T)}

 par(mfrow = c(2,1), mar=c(5,3,3,1)+0.1)
 par(mex=0.5,csi=0.11)
 
 SP500 <- matrix(scan("../datasets/SP500",skip=15),ncol=5,byrow=T)
 SP500 <- rev(SP500[1:2529,5])            #closing prices from Jan 2,90
 SP500 <- log(as.numeric(SP500))
 

 ###########  one period return from Jan. 3, 1990   #############
 r1 <- diff(SP500)^2 
 lambda <- 0.97
 xlam <- r1*(1-lambda)
 xlam[1] <- r1[1]
 vol1 <- filter(xlam, filter = lambda, method = "rec")
 vol1 <- as.vector(25*vol1)         #converting one-day volatility
				    #into 25 day volatility

 ########## 25-day return from Jan. 27, 1990   ###############
 r25 <- SP500[26:length(SP500)] - SP500[1:(length(SP500)-25)] 
 r25 <- r25^2
 xlam <- r25*(1-lambda)
 xlam[1] <- r25[1]
 vol25 <- filter(xlam, filter = lambda, method = "rec")
 vol25 <- as.vector(vol25)


 ########## Fitting:  predicting future 25-day volatility from
 ########## vol25 and vol1, starting from Jan. 2, 1991 
 ########## (254 trading-days away Jan. 2, 1990), to April 30, 1996
 ########## (1500 trading away from Jan. 2,90)
 ###################################################################

 y <- r25[253:1475]              #future 25-day squared return
 vola1 <- vol1[252:1474]         #observed 1-day volatility
 vola25 <- vol25[(253-25):(1475-25)] #observed 25-day volatility

 ############ taking a subset to reduce the influence of outliers ###
 sub <- (y < quantile(y,0.975)) + (y > quantile(y,0.025))
 sub <- (1:length(sub))[sub==2]
 ys <- y[sub]
 vola1s  <- vola1[sub]
 vola25s <- vola25[sub]
 res.gam   <- gam(ys ~ lo(vola1s,span=0.75) + lo(vola25s,span=0.75))
 res.term  <- predict(res.gam, type="term")

 ############ plotting of additive function #####################

 ord <- order(vola1s)
 plot(vola1s[ord],  res.term[ord,1], type="l",xlab="(a)")
 title("Additive component for 1-day volatility")

 ord <- order(vola25s)
 plot(vola25s[ord],  res.term[ord,2],type="l",xlab="(b)")
 title("Additive component for 25-day volatility")
}
